.. _dev_guide:

*****************
Developer's Guide
*****************

Please go `here <https://docs.sunpy.org/en/latest/dev_guide/index.html>`__ for our up to date developer's guide.

.. toctree::
   :maxdepth: 2

   stability
